@@ -22,7 +22,7 @@ source $(git rev-parse --show-toplevel)/vendor/github.com/tektoncd/plumbing/scri
 
 cd ${REPO_ROOT_DIR}
 
-VERSION="master"
+VERSION="release-0.23"
 
 # The list of dependencies that we track at HEAD and periodically
 # float forward in this repository.
@@ -46,9 +46,17 @@ if (( GO_GET )); then
   go get -d ${FLOATING_DEPS[@]}
 fi
 
-
 # Prune modules.
 go mod tidy
 go mod vendor
 
+# Applying patches
+if [[ -d hack/patches ]];then
+    for f in hack/patches/*.patch;do
+        [[ -f ${f} ]] || continue
+        # Apply patches but do not commit
+        git apply ${f}
+    done
+fi
+
 update_licenses third_party/
